# Value Object for Grade Point Average

This package a standardized interface for representing grade point averages in PHP at NC State University. It is an implementation of [REG 02.50.03](http://policies.ncsu.edu/regulation/reg-02-50-03) and supports mapping of numeric grade point values to ASCII grade representations and the reverse.

![](docs/out.gif)

## Install

Via Composer

``` json
{
    "repositories": [
        {
            "type": "vcs",
            "url": "git@github.ncsu.edu:ncstate-contrib/gpa.git"
        }
    ],
    "require": {
        "ncsu/gpa": "~1.0"
    }
}
```

## Usage

**Representing a GPA value and displaying associated grade**

``` php
$gpa = GPA::fromNative(4.33333);
$gpa->grade() === 'A+'   // true
$gpa->points() === 4.333   // true

// ...

GPA::fromNative(4)->grade() === 'A'       // true
GPA::fromNative(3.667)->grade() === 'A-'  // true
GPA::fromNative(3.333)->grade() === 'B+'  // true
GPA::fromNative(3)->grade() === 'B'       // true
GPA::fromNative(2.667)->grade() === 'B-'  // true
GPA::fromNative(2.333)->grade() === 'C+'  // true
GPA::fromNative(2)->grade() === 'C'       // true
GPA::fromNative(1.667)->grade() === 'C-'  // true
GPA::fromNative(1.333)->grade() === 'D+'  // true
GPA::fromNative(1)->grade() === 'D'       // true
GPA::fromNative(0.667)->grade() === 'D-'  // true
GPA::fromNative(0)->grade() === 'F'       // true
```

**Comparing GPA values**

``` php
$gpa = GPA::fromNative(3.345)
$higher = GPA::fromNative(3.984)
$lower = GPA::fromNative(3.145)

$gpa->gte($lower)  // true
$gpa->lte($higher) // true

$gpa->gt($higher)  // false
$gpa->lt($lower)   // false
```

**Make GPA value from letter grade**

``` php
$perfectGpa = GPA::fromGrade('A+');
$failingGpa = GPA::fromGrade('F');

$perfectGpa->points() === 4.333   // true
$failingGpa->points() === 0       // true
```

**Simple assertions**

``` php
// Has met "C-wall" requirements.
$met = GPA::fromGrade('B+');
$unmet = GPA::fromGrade('F');

$met->meetsCWall()   // true
$unmet->meetsCWall() // false
```

## Testing

``` bash
$ phpunit
```

## Contributing

Please see [CONTRIBUTING](CONTRIBUTING.md) for details.

## Security

If you discover any security related issues, please email mdwheele@ncsu.edu instead of using the issue tracker.

## Credits

- [Dustin Wheeler](https://github.ncsu.edu/mdwheele)
- [All Contributors](../../contributors)

## License

The MIT License (MIT). Please see [License File](LICENSE.md) for more information.
